{#
  Licensed to the Apache Software Foundation (ASF) under one
  or more contributor license agreements.  See the NOTICE file
  distributed with this work for additional information
  regarding copyright ownership.  The ASF licenses this file
  to you under the Apache License, Version 2.0 (the
  "License"); you may not use this file except in compliance
  with the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing,
  software distributed under the License is distributed on an
  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  KIND, either express or implied.  See the License for the
  specific language governing permissions and limitations
  under the License.
 #}

{% extends base_template %}
{% block page_title %}Datasets - {{ appbuilder.app_name }}{% endblock %}

{% block head_meta %}
  {{ super() }}
  <meta name="datasets_api" content="{{ url_for('Airflow.datasets_summary') }}">
  <meta name="dataset_api" content="{{ url_for('/api/v1.airflow_api_connexion_endpoints_dataset_endpoint_get_dataset', uri='__URI__') }}">
  <meta name="dataset_events_api" content="{{ url_for('/api/v1.airflow_api_connexion_endpoints_dataset_endpoint_get_dataset_events') }}">
  <meta name="grid_url" content="{{ url_for('Airflow.grid', dag_id='__DAG_ID__') }}">
  <meta name="datasets_docs" content="{{ get_docs_url('concepts/datasets.html') }}">
  <meta name="dataset_dependencies_url" content="{{ url_for('Airflow.dataset_dependencies') }}">
{% endblock %}

{% block content %}
  {{ super() }}
  <div id="root">
    <div id="react-container"></div>
  </div>
{% endblock %}

{% block tail_js %}
  {{ super()}}
  <script>
    const stateColors = {{ state_color_mapping|tojson }};
  </script>
  <script src="{{ url_for_asset('datasets.js') }}"></script>
{% endblock %}
